@@ -6,7 +6,6 @@ from .schedule import _WiserSchedule, _WiserScheduleCollection
 from .rest_controller import _WiserRestController
 
 from .const import (
-    MAX_BOOST_INCREASE,
     TEMP_MINIMUM,
     TEMP_MAXIMUM,
     TEMP_OFF,
@@ -160,7 +159,7 @@ class _WiserRoom(object):
         """
         result = self._wiser_rest_controller._send_command(WISERROOM.format(self.id), cmd)
         if result:
-            _LOGGER.info(
+            _LOGGER.debug(
                 "Wiser room - {} command successful - {}".format(inspect.stack()[1].function, result)
             )
         return result
@@ -351,9 +350,7 @@ class _WiserRoom(object):
                 "RequestOverride": {
                     "Type": "Boost",
                     "DurationMinutes": duration,
-                    "IncreaseSetPointBy": tf._to_wiser_temp(inc_temp)
-                    if tf._to_wiser_temp(inc_temp) <= MAX_BOOST_INCREASE
-                    else MAX_BOOST_INCREASE,
+                    "IncreaseSetPointBy": tf._to_wiser_temp(inc_temp, "delta")
                 }
             }
         )
